==> devextreme-21.2.6-build-22040-1134.tgz: package/cjs/ui/scheduler/appointments/resizing/utils.js <==
/**
 * DevExtreme (cjs/ui/scheduler/appointments/resizing/utils.js)
 * Version: 21.2.5 (build 22040-1134)
 * Build date: Wed Feb 09 2022
 *
 * Copyright (c) 2012 - 2022 Developer Express Inc. ALL RIGHTS RESERVED
 * Read about DevExtreme licensing here: https://js.devexpress.com/Licensing/
 */
"use strict";
exports.normalizeStartDate = exports.normalizeEndDate = exports.getEndResizeAppointmentStartDate = void 0;
var _utils = _interopRequireDefault(require("../../utils.timeZone"));
var _appointmentAdapter = require("../../appointmentAdapter");
var _recurrence = require("../../recurrence");

function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : {
        default: obj
    }
}
var normalizeDate = function(options, date, sourceDate, isStartDate) {
    if (!options.considerTime) {
        return date
    }
    var result = new Date(date);
    result.setHours(sourceDate.getHours(), sourceDate.getMinutes(), sourceDate.getSeconds());
    var startDayHour = options.startDayHour,
        endDayHour = options.endDayHour,
        allDay = options.appointmentSettings.allDay;
    var minDate = new Date(date);
    var maxDate = new Date(date);
    minDate.setHours(startDayHour, 0, 0, 0);
    maxDate.setHours(endDayHour, 0, 0, 0);
    var isDateOutInterval = isStartDate ? result < minDate.getTime() || result >= maxDate.getTime() : result <= minDate.getTime() || result > maxDate.getTime();
    if (isDateOutInterval) {
        result = !allDay ? maxDate : minDate
    }
    return result
};
var applyTimeZone = function(sourceAppointment, startDate, endDate) {
    return _utils.default.getTimezoneOffsetChangeInMs(sourceAppointment.startDate, sourceAppointment.endDate, startDate, endDate)
};
var getEndResizeAppointmentStartDate = function(options, startDate) {
    var result = startDate;
    var _options$appointmentS = options.appointmentSettings,
        allDay = _options$appointmentS.allDay,
        sourceAppointment = _options$appointmentS.info.sourceAppointment,
        timeZoneCalculator = options.timeZoneCalculator,
        dataAccessors = options.dataAccessors,
        handles = options.handles;
    var appointmentAdapter = (0, _appointmentAdapter.createAppointmentAdapter)(sourceAppointment, dataAccessors, timeZoneCalculator);
    var recurrenceProcessor = (0, _recurrence.getRecurrenceProcessor)();
    var recurrenceRule = appointmentAdapter.recurrenceRule,
        startDateTimeZone = appointmentAdapter.startDateTimeZone;
    var isRecurrent = recurrenceProcessor.isValidRecurrenceRule(recurrenceRule);
    if (!handles.top && !isRecurrent && !allDay) {
        result = timeZoneCalculator.createDate(startDate, {
            appointmentTimeZone: startDateTimeZone,
            path: "toGrid"
        })
    }
    return result
};
exports.getEndResizeAppointmentStartDate = getEndResizeAppointmentStartDate;
var normalizeStartDate = function(options, startDate, sourceStartDate) {
    var sourceAppointment = options.appointmentSettings.info.sourceAppointment;
    var normalizedStartDate = normalizeDate(options, startDate, sourceStartDate, true);
    var timeZoneOffset = applyTimeZone(sourceAppointment, normalizedStartDate, sourceAppointment.endDate);
    return new Date(normalizedStartDate.getTime() + timeZoneOffset)
};
exports.normalizeStartDate = normalizeStartDate;
var normalizeEndDate = function(options, endDate, sourceEndDate) {
    var sourceAppointment = options.appointmentSettings.info.sourceAppointment;
    var normalizedEndDate = normalizeDate(options, endDate, sourceEndDate, false);
    var timeZoneOffset = applyTimeZone(sourceAppointment, sourceAppointment.startDate, normalizedEndDate);
    return new Date(normalizedEndDate.getTime() + timeZoneOffset)
};
exports.normalizeEndDate = normalizeEndDate;

==> devextreme-21.2.8-build-22152-1752.tgz: package/cjs/ui/scheduler/appointments/resizing/utils.js <==
/**
 * DevExtreme (cjs/ui/scheduler/appointments/resizing/utils.js)
 * Version: 21.2.7 (build 22152-1752)
 * Build date: Wed Jun 01 2022
 *
 * Copyright (c) 2012 - 2022 Developer Express Inc. ALL RIGHTS RESERVED
 * Read about DevExtreme licensing here: https://js.devexpress.com/Licensing/
 */
"use strict";
exports.normalizeStartDate = exports.normalizeEndDate = void 0;
var normalizeDate = function(options, date, sourceDate, isStartDate) {
    if (!options.considerTime) {
        return date
    }
    var result = new Date(date);
    result.setHours(sourceDate.getHours(), sourceDate.getMinutes(), sourceDate.getSeconds());
    var startDayHour = options.startDayHour,
        endDayHour = options.endDayHour,
        allDay = options.appointmentSettings.allDay;
    var minDate = new Date(date);
    var maxDate = new Date(date);
    minDate.setHours(startDayHour, 0, 0, 0);
    maxDate.setHours(endDayHour, 0, 0, 0);
    var isDateOutInterval = isStartDate ? result < minDate.getTime() || result >= maxDate.getTime() : result <= minDate.getTime() || result > maxDate.getTime();
    if (isDateOutInterval) {
        result = !allDay ? maxDate : minDate
    }
    return result
};
var normalizeStartDate = function(options, startDate, sourceStartDate) {
    return normalizeDate(options, startDate, sourceStartDate, true)
};
exports.normalizeStartDate = normalizeStartDate;
var normalizeEndDate = function(options, endDate, sourceEndDate) {
    return normalizeDate(options, endDate, sourceEndDate, false)
};
exports.normalizeEndDate = normalizeEndDate;
